AccountController class
Inheritance
Object
GetLifeCycle
DisposableInterface
GetxController
AccountController
Implemented types
Properties
authenticationPages
↔ RxMap<AuthPage , Widget >
getter/setter pair
currentPageIndex
↔ RxInt
Authentication Navigation
getter/setter pair
hashCode
→ int
The hash code for this object.
no setter inherited
hasListeners
→ bool
no setter inherited
initialized
→ bool
Checks whether the controller has already been initialized.
no setter inherited
isClosed
→ bool
Checks whether the controller has already been closed.
no setter inherited
listeners
→ int
no setter inherited
onDelete
→ InternalFinalCallback<void >
Internal callback that starts the cycle of this controller.
final inherited
onStart
→ InternalFinalCallback<void >
Called at the exact moment the widget is allocated in memory.
It uses an internal "callable" type, to avoid any @overrides in subclases.
This method should be internal and is required to define the
lifetime cycle of the subclass.
final inherited
runtimeType
→ Type
A representation of the runtime type of the object.
no setter inherited
user
↔ UserModel
getter/setter pair
Methods
$configureLifeCycle ()
→ void
inherited
accountLogin ({required String username , required String password })
→ Future <void >
Login, SignUp, SignOut
accountSignUp ({required String username , required String eMail , required String password , required String repeatPassword , required AccountType accountType })
→ Future <void >
Account SignUp
addListener (GetStateUpdate listener )
→ Disposer
Register a closure to be called when the object notifies its listeners.
inherited
addListenerId (Object ? key , GetStateUpdate listener )
→ Disposer
inherited
deleteAccount ()
→ Future <void >
Delete Account
deleteProfilePhoto ()
→ Future <void >
Delete Profile Photo
dispose ()
→ void
inherited
disposeId (Object id )
→ void
To dispose an id from future updates(), this ids are registered
by GetBuilder() or similar, so is a way to unlink the state change with
the Widget from the Controller.
inherited
getCurrentAuthenticationPage ()
→ Widget
getIsLoggedIn ()
→ bool
handleHiddenAccountOperation ({required String operationName , String ? customErrorMessage , required Future <void > authOperation () })
→ Future <void >
initializeUserStream ()
→ void
mapAccountInformation ({required User accountInformation })
→ void
mapDatabaseInformation ({required DocumentSnapshot<Map <String , dynamic > > databaseField })
→ void
noSuchMethod (Invocation invocation )
→ dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyChildrens ()
→ void
inherited
onClose ()
→ void
Called before onDelete method. onClose might be used to
dispose resources used by the controller. Like closing events,
or streams before the controller is destroyed.
Or dispose objects that can potentially create some memory leaks,
like TextEditingControllers, AnimationControllers.
Might be useful as well to persist some data on disk.
inherited
onInit ()
→ void
Called immediately after the widget is allocated in memory.
You might use this to initialize something for the controller.
inherited
onReady ()
→ void
Called 1 frame after onInit(). It is the perfect place to enter
navigation events, like snackbar, dialogs, or a new route, or
async request.
inherited
refresh ()
→ void
inherited
refreshGroup (Object id )
→ void
inherited
removeListener (VoidCallback listener )
→ void
Remove a previously registered closure from the list of closures that the
object notifies.
inherited
removeListenerId (Object id , VoidCallback listener )
→ void
inherited
resendEmailVerification ()
→ Future <void >
Change E-Mail
resetPassword ({String ? eMail })
→ Future <void >
Password reset
setCurrentAuthenticationPage ({required AuthPage authPage })
→ void
signOut ()
→ Future <void >
Sign Out
toString ()
→ String
A string representation of this object.
inherited
update ([List <Object > ? ids , bool condition = true ])
→ void
Rebuilds GetBuilder each time you call update();
Can take a List of ids, that will only update the matching
GetBuilder( id: ),
ids can be reused among GetBuilders like group tags.
The update will only notify the Widgets, if condition is true.
inherited
updateAbout ({required String about })
→ Future <void >
Change E-Mail
updateEmail ({required String newEmail })
→ Future <void >
Change Profile Photo
updateNationality ({required String nationality })
→ Future <void >
Change E-Mail
updateUsername ({required String newUsername })
→ Future <void >
Change Username