UserModel class

Constructors

UserModel({String name = '', String id = '', AccountType accountType = AccountType.none, bool verified = false, String email = '', String imageUrl = '', String about = ''})
UserModel.fromJson(Map<String, dynamic> json)
factory

Properties

about String
getter/setter pair
accountType AccountType
getter/setter pair
email String
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
id String
getter/setter pair
imageUrl String
getter/setter pair
name String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
verified bool
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited